aboutsummaryrefslogtreecommitdiffstats
path: root/engine/gfx
diff options
context:
space:
mode:
authorSylvie <35663410+Rangi42@users.noreply.github.com>2024-08-04 10:05:33 -0400
committerGitHub <noreply@github.com>2024-08-04 10:05:33 -0400
commit77d051479bd0ed96cc2efdba52f837afd1e119c3 (patch)
tree72a22aeb8dd6edc10323f0ee72fe9dbf73e5481a /engine/gfx
parentIdentify wcd6d as wNameBuffer and others (#455) (diff)
downloadpokeyellow-77d051479bd0ed96cc2efdba52f837afd1e119c3.tar.gz
pokeyellow-77d051479bd0ed96cc2efdba52f837afd1e119c3.tar.xz
pokeyellow-77d051479bd0ed96cc2efdba52f837afd1e119c3.zip
Identify wcf91 as wCurPartySpecies, wCurItem, and wCurListMenuItem (#457)
Diffstat (limited to 'engine/gfx')
-rw-r--r--engine/gfx/mon_icons.asm4
-rw-r--r--engine/gfx/palettes.asm4
2 files changed, 4 insertions, 4 deletions
diff --git a/engine/gfx/palettes.asm b/engine/gfx/palettes.asm
index d97fbc55..f59b37ea 100644
--- a/engine/gfx/palettes.asm
+++ b/engine/gfx/palettes.asm
@@ -69,7 +69,7 @@ SetPal_StatusScreen:
ld de, wPalPacket
ld bc, $10
call CopyData
- ld a, [wcf91]
+ ld a, [wCurPartySpecies]
cp NUM_POKEMON_INDEXES + 1
jr c, .pokemon
ld a, $1 ; not pokemon
@@ -97,7 +97,7 @@ SetPal_Pokedex:
ld de, wPalPacket
ld bc, $10
call CopyData
- ld a, [wcf91]
+ ld a, [wCurPartySpecies]
call DeterminePaletteIDOutOfBattle
ld hl, wPalPacket + 3
ld [hl], a
diff --git a/engine/gfx/mon_icons.asm b/engine/gfx/mon_icons.asm
index 73b1632f..53fabc6d 100644
--- a/engine/gfx/mon_icons.asm
+++ b/engine/gfx/mon_icons.asm
@@ -196,9 +196,9 @@ WriteMonPartySpriteOAMBySpecies:
UnusedPartyMonSpriteFunction:
; This function is unused and doesn't appear to do anything useful. It looks
; like it may have been intended to load the tile patterns and OAM data for
; the mon party sprite associated with the species in [wcf91].
; However, its calculations are off and it loads garbage data.
- ld a, [wcf91]
+ ld a, [wCurPartySpecies]
call GetPartyMonSpriteID
push af
ld hl, vSprites tile $00
@@ -196,9 +196,9 @@ WriteMonPartySpriteOAMBySpecies:
; This function is unused and doesn't appear to do anything useful. It looks
; like it may have been intended to load the tile patterns and OAM data for
-; the mon party sprite associated with the species in [wcf91].
+; the mon party sprite associated with the species in [wCurPartySpecies].
; However, its calculations are off and it loads garbage data.